@@ -8,7 +8,7 @@ data_plot.compare_performance <- function(x, data = NULL, ...) {
   if ("BF" %in% colnames(x)) x$BF[is.na(x$BF)] <- 1
 
   # normalize indices, for better comparison
-  x <- datawizard::rescale(x, exclude = "Model", to = c(.1, 1))
+  x <- datawizard::rescale(x, exclude = "Model", to = c(0.1, 1))
 
   # recode some indices, so higher values = better fit
   for (i in c("AIC", "BIC", "AICc", "RMSE", "Sigma")) {
@@ -103,7 +103,7 @@ plot.see_compare_performance <- function(x, size_line = 1, ...) {
     group = .data$Model,
     fill = .data$Model
   )) +
-    geom_polygon(size = size_line, alpha = .05) +
+    geom_polygon(linewidth = size_line, alpha = 0.05) +
     coord_radar() +
     scale_y_continuous(limits = c(0, 1), labels = NULL) +
     add_plot_attributes(x) +
